
dialogId("nog-v-zvlastni", "font_big", "This is a very strange room.")
dialogStr("Dit is een heel erg vreemde kamer.")


dialogId("nog-m-uvedom0", "font_small", "You need to realize that the steel cylinder surrounding us is only an object.")
dialogStr("Je moet je realiseren dat de stalen cylinder om ons heen een doodgewoon ding is.")


dialogId("nog-m-uvedom1", "font_small", "All in all there are only four squares of wall here.")
dialogStr("Alles bij elkaar zijn er hier maar vier vlakjes muur.")


dialogId("nog-v-smetiste0", "font_big", "This trash heap is weird...")
dialogStr("Dit is een rare vuilnishoop...")


dialogId("nog-v-smetiste1", "font_big", "This garbage heap still looks kind of strange...")
dialogStr("Deze berg troep ziet er wel een beetje raar uit...")

